@@ -32,7 +32,7 @@ wwwAutolink :: Monad m => InlineParser m Text
 wwwAutolink = try $ do
   lookAhead $ satisfyWord (== "www")
   validDomain
-  linkSuffix
+  linkPath 0
   return "http://"
 
 validDomain :: Monad m => InlineParser m ()
@@ -47,29 +47,40 @@ validDomain = do
   domainPart
   skipMany1 $ try (symbol '.' >> domainPart)
 
-linkSuffix :: Monad m => InlineParser m ()
-linkSuffix = try $ do
-  toks <- getInput
-  let possibleSuffixTok (Tok (Symbol c) _ _) =
-        c `notElem` ['<','>','{','}','|','\\','^','[',']','`']
-      possibleSuffixTok (Tok WordChars _ _) = True
-      possibleSuffixTok _ = False
-  let isDroppable (Tok (Symbol c) _ _) =
-         c `elem` ['?','!','.',',',':','*','_','~']
-      isDroppable _ = False
-  let numToks = case dropWhile isDroppable $
-                    reverse (takeWhile possibleSuffixTok toks) of
-                     (Tok (Symbol ')') _ _ : xs)
-                       | length [t | t@(Tok (Symbol '(') _ _) <- xs] <=
-                         length [t | t@(Tok (Symbol ')') _ _) <- xs]
-                       -> length xs
-                     (Tok (Symbol ';') _ _
-                        : Tok WordChars _ _
-                        : Tok (Symbol '&') _ _
-                        : xs) -> length xs
-                     xs -> length xs
-  count numToks anyTok
-  return ()
+linkPath :: Monad m => Int -> InlineParser m ()
+linkPath openParens = optional $ do
+   Tok tt _ _ <- lookAhead anyTok
+   case tt of
+     Symbol '&' -> optional $
+      try (symbol '&' *>
+           notFollowedBy
+             (try (satisfyWord (const True) *> symbol ';' *> linkEnd)) *>
+           linkPath openParens)
+     Symbol '(' -> symbol '(' *> linkPath (openParens + 1)
+     Symbol ')' -> optional $ guard (openParens > 0) *> symbol ')' *> linkPath (openParens - 1)
+     Symbol '<' -> pure ()
+     Symbol c | isTrailingPunctuation c -> optional $
+         try (do skipMany1 trailingPunctuation
+                 pos <- getPosition
+                 linkPath openParens
+                 pos' <- getPosition
+                 guard (pos' > pos)) *> linkPath openParens
+     LineEnd -> pure ()
+     Spaces -> pure ()
+     _ -> anyTok *> linkPath openParens
+
+linkEnd :: Monad m => InlineParser m ()
+linkEnd = try $ skipMany trailingPunctuation *> (void whitespace <|> eof)
+
+trailingPunctuation :: Monad m => InlineParser m Tok
+trailingPunctuation =
+  satisfyTok (\t -> case tokType t of
+                           Symbol c -> isTrailingPunctuation c
+                           _ -> False)
+
+isTrailingPunctuation :: Char -> Bool
+isTrailingPunctuation =
+  (`elem` ['!', '"', '\'', ')', '*', ',', '.', ':', ';', '?', '_', '~', '<'])
 
 urlAutolink :: Monad m => InlineParser m Text
 urlAutolink = try $ do
@@ -78,7 +89,7 @@ urlAutolink = try $ do
   symbol '/'
   symbol '/'
   validDomain
-  linkSuffix
+  linkPath 0
   return ""
 
 emailAutolink :: Monad m => InlineParser m Text
